==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/ia.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migration in progresso. Per favor, attende usque le migration es finite.",
    "Migration started …" : "Migration initiate...",
    "Saved" : "Salveguardate",
    "Not saved" : "Non salveguardate",
    "Email sent" : "Message de e-posta inviate",
    "Private" : "Private",
    "Public" : "Public",
    "Unable to change password" : "Impossibile cambiar contrasigno",
    "Very weak password" : "Contrasigno multo debile",
    "Weak password" : "Contrasigno debile",
    "So-so password" : "Contrasigno plus o minus acceptabile",
    "Good password" : "Contrasigno bon",
    "Strong password" : "Contrasigno forte",
    "Select a profile picture" : "Selectiona un pictura de profilo",
    "Groups" : "Gruppos",
    "Couldn't remove app." : "Impossibile remover application.",
    "Couldn't update app." : "Impossibile actualisar application.",
    "Wrong password" : "Contrasigno incorrecte",
    "No user supplied" : "Nulle usator fornite",
    "Authentication error" : "Error in authentication",
    "Wrong admin recovery password. Please check the password and try again." : "Le contrasigno administrator pro recuperation de datos es incorrecte. Per favor, verifica le contrasigno e tenta de novo.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Installation e actualisation de applicationes via le App Store o Compartimento del Nube Federate",
    "Federated Cloud Sharing" : "Compartimento del Nube Federate",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Un problema occurreva durante le invio del e-posta. Per favor, revide tu configurationes. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Tu debe configurar tu e-posta de usator ante esser capace a inviar e-posta de test.",
    "Invalid mail address" : "Adresse de e-posta non valide",
    "Settings saved" : "Configurationes salveguardate",
    "Unable to change full name" : "Impossibile cambiar nomine complete",
    "Unable to change email address" : "Impossibile cambiar adresse de e-posta",
    "Your %s account was created" : "Tu conto %s esseva create",
    "Settings" : "Configurationes",
    "Personal" : "Personal",
    "Sharing" : "Compartente",
    "Personal info" : "Information personal",
    "Create" : "Crear",
    "Delete" : "Deler",
    "Unlimited" : "Ilimitate",
    "Save changes" : "Salveguardar cambios",
    "All" : "Tote",
    "Disable" : "Disactivar",
    "Visit website" : "Visitar sito web",
    "Report a bug" : "Reportar un defecto",
    "User documentation" : "Documentation de usator",
    "Admin documentation" : "Documentation de administrator",
    "Developer documentation" : "Documentation de disveloppator",
    "No apps found for your version" : "Nulle application trovate pro tu version",
    "Allow filesystem access" : "Permitter accesso a systema de files",
    "Rename" : "Renominar",
    "Revoke" : "Revocar",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pro Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Synchronisar cliente - {os}",
    "This session" : "Iste session",
    "Device" : "Dispositivo",
    "Last activity" : "Ultime activitate",
    "App name" : "Nomine del application",
    "Create new app password" : "Crear un nove contrasigno pro application",
    "Use the credentials below to configure your app or device." : "Usa le datos de authentication infra pro configurar tu application o dispositivo.",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Done" : "Preste",
    "Copied!" : "Copiate!",
    "Copy" : "Copiar",
    "Cancel" : "Cancellar",
    "Display name" : "Monstrar nomine",
    "Email" : "E-posta",
    "Close" : "Clauder",
    "Quota" : "Quota",
    "Language" : "Lingua",
    "Default quota" : "Quota predefinite",
    "Add" : "Adder",
    "Details" : "Detalios",
    "Add group" : "Adder gruppo",
    "Everyone" : "Totos",
    "Admins" : "Administratores",
    "Send email to new user" : "Inviar message de e-posta a nove usator",
    "Enable" : "Activar",
    "Never" : "Nunquam",
    "App update" : "Application actualisate",
    "Administrator documentation" : "Documentation de administrator",
    "Documentation" : "Documentation",
    "Forum" : "Foro",
    "None" : "Nulle",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servitor de e-posta",
    "Open documentation" : "Aperir documentation",
    "Send mode" : "Modo de invio",
    "Encryption" : "Cryptographia",
    "From address" : "De adresse",
    "Authentication method" : "Methodo de authentication",
    "Authentication required" : "Authentication requirite",
    "Server address" : "Adresse del servitor",
    "Port" : "Porto",
    "Credentials" : "Datos de authentication",
    "SMTP Username" : "Nomine de usator SMTP",
    "SMTP Password" : "Contrasigno SMTP",
    "Save" : "Salveguardar",
    "Test email settings" : "Testar configurationes de e-posta",
    "Send email" : "Inviar message de e-posta",
    "Security & setup warnings" : "Securitate e advertimentos de configuration",
    "Version" : "Version",
    "Enable encryption" : "Activar cryptographia",
    "Select default encryption module:" : "Selectionar modulo de cryptographia standard",
    "Start migration" : "Initiar migration",
    "Expire after " : "Expirar post",
    "days" : "dies",
    "Enforce expiration date" : "Exiger data de expiration",
    "Allow users to share via link" : "Permitter usatores compartir via ligamine",
    "Allow public uploads" : "Permitter incargas public",
    "Enforce password protection" : "Exiger protection per contrasigno",
    "Profile picture" : "Pictura de profilo",
    "Upload new" : "Incargar nove",
    "Select from Files" : "Selectionar de Files",
    "Remove image" : "Remover imagine",
    "png or jpg, max. 20 MB" : "formato png o jpg, dimension maxime 20 MB",
    "Picture provided by original account" : "Pictura fornite per conto original",
    "Choose as profile picture" : "Selectiona como pictura de profilo",
    "Full name" : "Nomine complete",
    "Your email address" : "Tu adresse de e-posta",
    "No email address set" : "Nulle adresse de e-posta definite",
    "For password reset and notifications" : "Pro reinitialisation de contrasigno e invio de notificationes",
    "Phone number" : "Numero de telephono",
    "Your phone number" : "Tu numero de telephono",
    "Address" : "Adresse",
    "Your postal address" : "Tu adresse postal",
    "Website" : "Sito web",
    "Twitter" : "Twitter",
    "Help translate" : "Adjuta a traducer",
    "Current password" : "Contrasigno actual",
    "New password" : "Nove contrasigno",
    "Change password" : "Cambiar contrasigno",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Un error occurreva. Per favor, incarga un certificato PEM codificate in ASCII",
    "Valid until {date}" : "Valide usque {date}",
    "Local" : "Local",
    "Only visible to local users" : "Solmente visibile a usatores local",
    "Only visible to you" : "Solmente visibile a tu",
    "Contacts" : "Contactos",
    "Visible to local users and to trusted servers" : "Visibile a usatores local e a servitores fiduciari",
    "by" : "per",
    "SSL Root Certificates" : "Certificatos Root SSL",
    "Common Name" : "Nomine Commun",
    "Valid until" : "Valide usque",
    "Issued By" : "Emittite per",
    "Valid until %s" : "Valide usque %s",
    "Import root certificate" : "Importar certificato root"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/ia.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migration in progresso. Per favor, attende usque le migration es finite.",
    "Migration started …" : "Migration initiate...",
    "Saved" : "Salveguardate",
    "Not saved" : "Non salveguardate",
    "Email sent" : "Message de e-posta inviate",
    "Private" : "Private",
    "Local" : "Local",
    "Unable to change password" : "Impossibile cambiar contrasigno",
    "Very weak password" : "Contrasigno multo debile",
    "Weak password" : "Contrasigno debile",
    "So-so password" : "Contrasigno plus o minus acceptabile",
    "Good password" : "Contrasigno bon",
    "Strong password" : "Contrasigno forte",
    "Select a profile picture" : "Selectiona un pictura de profilo",
    "Groups" : "Gruppos",
    "Couldn't remove app." : "Impossibile remover application.",
    "Couldn't update app." : "Impossibile actualisar application.",
    "Wrong password" : "Contrasigno incorrecte",
    "No user supplied" : "Nulle usator fornite",
    "Authentication error" : "Error in authentication",
    "Wrong admin recovery password. Please check the password and try again." : "Le contrasigno administrator pro recuperation de datos es incorrecte. Per favor, verifica le contrasigno e tenta de novo.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Installation e actualisation de applicationes via le App Store o Compartimento del Nube Federate",
    "Federated Cloud Sharing" : "Compartimento del Nube Federate",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Un problema occurreva durante le invio del e-posta. Per favor, revide tu configurationes. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Tu debe configurar tu e-posta de usator ante esser capace a inviar e-posta de test.",
    "Invalid mail address" : "Adresse de e-posta non valide",
    "Settings saved" : "Configurationes salveguardate",
    "Unable to change full name" : "Impossibile cambiar nomine complete",
    "Unable to change email address" : "Impossibile cambiar adresse de e-posta",
    "Your %s account was created" : "Tu conto %s esseva create",
    "Settings" : "Configurationes",
    "Personal" : "Personal",
    "Sharing" : "Compartente",
    "Personal info" : "Information personal",
    "Create" : "Crear",
    "Delete" : "Deler",
    "Unlimited" : "Ilimitate",
    "Save changes" : "Salveguardar cambios",
    "All" : "Tote",
    "Disable" : "Disactivar",
    "Visit website" : "Visitar sito web",
    "Report a bug" : "Reportar un defecto",
    "User documentation" : "Documentation de usator",
    "Admin documentation" : "Documentation de administrator",
    "Developer documentation" : "Documentation de disveloppator",
    "No apps found for your version" : "Nulle application trovate pro tu version",
    "Allow filesystem access" : "Permitter accesso a systema de files",
    "Rename" : "Renominar",
    "Revoke" : "Revocar",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pro Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Synchronisar cliente - {os}",
    "This session" : "Iste session",
    "Device" : "Dispositivo",
    "Last activity" : "Ultime activitate",
    "App name" : "Nomine del application",
    "Create new app password" : "Crear un nove contrasigno pro application",
    "Use the credentials below to configure your app or device." : "Usa le datos de authentication infra pro configurar tu application o dispositivo.",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Done" : "Preste",
    "Copied!" : "Copiate!",
    "Copy" : "Copiar",
    "Cancel" : "Cancellar",
    "Display name" : "Monstrar nomine",
    "Email" : "E-posta",
    "Close" : "Clauder",
    "Quota" : "Quota",
    "Language" : "Lingua",
    "Default quota" : "Quota predefinite",
    "Add" : "Adder",
    "Details" : "Detalios",
    "Add group" : "Adder gruppo",
    "Everyone" : "Totos",
    "Admins" : "Administratores",
    "Send email to new user" : "Inviar message de e-posta a nove usator",
    "Enable" : "Activar",
    "Never" : "Nunquam",
    "App update" : "Application actualisate",
    "Administrator documentation" : "Documentation de administrator",
    "Documentation" : "Documentation",
    "Forum" : "Foro",
    "None" : "Nulle",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servitor de e-posta",
    "Open documentation" : "Aperir documentation",
    "Send mode" : "Modo de invio",
    "Encryption" : "Cryptographia",
    "From address" : "De adresse",
    "Authentication method" : "Methodo de authentication",
    "Authentication required" : "Authentication requirite",
    "Server address" : "Adresse del servitor",
    "Port" : "Porto",
    "Credentials" : "Datos de authentication",
    "SMTP Username" : "Nomine de usator SMTP",
    "SMTP Password" : "Contrasigno SMTP",
    "Save" : "Salveguardar",
    "Test email settings" : "Testar configurationes de e-posta",
    "Send email" : "Inviar message de e-posta",
    "Security & setup warnings" : "Securitate e advertimentos de configuration",
    "Version" : "Version",
    "Enable encryption" : "Activar cryptographia",
    "Select default encryption module:" : "Selectionar modulo de cryptographia standard",
    "Start migration" : "Initiar migration",
    "Expire after " : "Expirar post",
    "days" : "dies",
    "Enforce expiration date" : "Exiger data de expiration",
    "Allow public uploads" : "Permitter incargas public",
    "Enforce password protection" : "Exiger protection per contrasigno",
    "Profile picture" : "Pictura de profilo",
    "Upload new" : "Incargar nove",
    "Select from Files" : "Selectionar de Files",
    "Remove image" : "Remover imagine",
    "png or jpg, max. 20 MB" : "formato png o jpg, dimension maxime 20 MB",
    "Picture provided by original account" : "Pictura fornite per conto original",
    "Choose as profile picture" : "Selectiona como pictura de profilo",
    "Full name" : "Nomine complete",
    "Your email address" : "Tu adresse de e-posta",
    "No email address set" : "Nulle adresse de e-posta definite",
    "For password reset and notifications" : "Pro reinitialisation de contrasigno e invio de notificationes",
    "Phone number" : "Numero de telephono",
    "Your phone number" : "Tu numero de telephono",
    "Address" : "Adresse",
    "Your postal address" : "Tu adresse postal",
    "Website" : "Sito web",
    "Twitter" : "Twitter",
    "Help translate" : "Adjuta a traducer",
    "Current password" : "Contrasigno actual",
    "New password" : "Nove contrasigno",
    "Change password" : "Cambiar contrasigno",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Un error occurreva. Per favor, incarga un certificato PEM codificate in ASCII",
    "Valid until {date}" : "Valide usque {date}",
    "Only visible to local users" : "Solmente visibile a usatores local",
    "Only visible to you" : "Solmente visibile a tu",
    "Contacts" : "Contactos",
    "Visible to local users and to trusted servers" : "Visibile a usatores local e a servitores fiduciari",
    "Public" : "Public",
    "by" : "per",
    "SSL Root Certificates" : "Certificatos Root SSL",
    "Common Name" : "Nomine Commun",
    "Valid until" : "Valide usque",
    "Issued By" : "Emittite per",
    "Valid until %s" : "Valide usque %s",
    "Import root certificate" : "Importar certificato root",
    "Allow users to share via link" : "Permitter usatores compartir via ligamine"
},
"nplurals=2; plural=(n != 1);");
